"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _gracefulFs = require("graceful-fs");

var _gracefulFs2 = _interopRequireDefault(_gracefulFs);

var _mkdirp = require("mkdirp");

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _verify = require("./verify");

var _verify2 = _interopRequireDefault(_verify);

var _glyphExtractor = require("./glyph-extractor");

var _glyphExtractor2 = _interopRequireDefault(_glyphExtractor);

var _pngGenerator = require("./png-generator");

var _pngGenerator2 = _interopRequireDefault(_pngGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultConfig = {};

function mainBlaster(fontFile, destinationFolder, userConfig) {
  var config = Object.assign({}, defaultConfig, userConfig || {});
  var svgFontContent = _gracefulFs2.default.readFileSync(fontFile, "utf-8");

  (0, _glyphExtractor2.default)(svgFontContent, config.filenames, function (characterSvgs) {
    console.info("Found " + characterSvgs.length + " available icons in the font");
    console.info("Generating SVG content for each character...");

    var svgDir = _path2.default.resolve(process.cwd(), _path2.default.join(destinationFolder, "svg"));
    var pngDir = _path2.default.resolve(process.cwd(), _path2.default.join(destinationFolder, "png"));

    if (!_gracefulFs2.default.existsSync(svgDir)) _mkdirp2.default.sync(svgDir);

    var savedIcons = [];
    characterSvgs.forEach(function (char) {
      var filename = char.name ? char.name : char.code;
      //If a subset of icons set was requested, ignore any others that are not within the subset
      if (config.icons && config.icons.length && config.icons.indexOf(char.code) === -1 && config.icons.indexOf(filename) === -1) {
        return;
      }
      savedIcons.push(char);
      _gracefulFs2.default.writeFileSync(_path2.default.join(svgDir, filename + ".svg"), char.svg);
    });
    console.info("Saved " + savedIcons.length + " files to " + svgDir);

    if (config.png && !isNaN(config.png)) {
      console.info("Generating PNG images - this may take a minute...");
      (0, _pngGenerator2.default)(svgDir, pngDir, config.png);
    }

    (0, _verify2.default)(svgFontContent, savedIcons, config.png, destinationFolder);
  }, config.cleanCharacter);
}

exports.default = mainBlaster;
module.exports = exports["default"];