"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _gracefulFs = require("graceful-fs");

var _gracefulFs2 = _interopRequireDefault(_gracefulFs);

var _svg2ttf = require("svg2ttf");

var _svg2ttf2 = _interopRequireDefault(_svg2ttf);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function generateVerifyFile(svgFont, iconSet, withPng, toFolder) {
  //Convert the SVG file into a TTF file so that more browsers can parse and show it
  var ttf = (0, _svg2ttf2.default)(svgFont, {});
  _gracefulFs2.default.writeFileSync(_path2.default.join(toFolder, "source-font.ttf"), new Buffer(ttf.buffer));

  //load the template for the verification file which contains some generic HTML
  var htmlTemplate = _gracefulFs2.default.readFileSync(_path2.default.join(__dirname, "..", "/resources/verify.html"), "utf-8");
  var iconContent = [];
  var cssRules = [];

  //Add a header to to the table
  iconContent.push("<div class=\"row\">\n    <div class=\"col icon-ref header\">&nbsp;</div>\n    <div class=\"col header\">Font Icon</div>\n    <div class=\"col header\">SVG Image</div>\n    " + (withPng ? '<div class="col header">PNG Image</div>' : "") + "\n    </div>");

  //for reach icon in the set, add a reference from the original font
  //then add a reference to the generated SVG image
  //then optionally add the reference to the PNG image if one was created

  iconSet.forEach(function (iconInfo) {
    cssRules.push(".blast-" + iconInfo.ref + ":before { content: \"\\" + iconInfo.code + "\"}\n");
    iconContent.push("\n      <div class=\"row\">\n        <div class=\"col icon-ref\">" + iconInfo.ref + "</div>\n        <div class=\"col\"><i class=\"blast-" + iconInfo.ref + "\"></i></div>\n        <div class=\"col\"><img class=\"svg-icon\" src=\"svg/" + iconInfo.ref + ".svg\"/></div>\n        " + (withPng ? '<div class="col"><img class="png-icon" src="png/' + iconInfo.ref + '.png"/></div>' : "") + "\n        </div>");
  });
  //poor man's templating
  htmlTemplate = htmlTemplate.replace(/_height_/g, 130);
  htmlTemplate = htmlTemplate.replace(/_iconRules_/g, cssRules.join(""));
  htmlTemplate = htmlTemplate.replace(/_iconContent_/g, iconContent.join(""));
  //generate the html test file
  _gracefulFs2.default.writeFileSync(_path2.default.join(toFolder, "verify.html"), htmlTemplate);
}

exports.default = generateVerifyFile;
module.exports = exports["default"];